@@ -194,17 +194,6 @@ sub _set_message
 	my $self = shift;
 	my $msg = shift;
 	
-	if ($msg)
-	{
-		# replace embedded newlines/carriage returns/tabs with plain spaces and
-		# then trim edges
-		#
-		$msg =~ s#[\n\r\t]# #g;
-		$msg =~ s#^\s*##;
-		$msg =~ s#\s*$##;
-		$msg = undef if length($msg) == 0;
-	}
-	
 	$self->{$ATTR_message} = $msg;
 }
 
